@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: DNSName.cpp,v 1.9 2006/09/10 22:40:36 vkurland Exp $
+  $Id: DNSName.cpp,v 1.10 2006/11/06 06:20:40 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -69,9 +69,10 @@ void DNSName::loadFromSource() throw(FWException)
             a->setAddress( i->toString() );
             addRef(a);
         }
-    } catch (FWException)
+    } catch (const FWException &ex)
     {
-        
+        cerr << "Error resolving dns name " << getSourceName() << ": '"
+             << ex.toString() << "'" << endl;
     }
 }
 
