@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: FWOptions.cpp,v 1.5 2006/03/16 05:33:24 vkurland Exp $
+  $Id: FWOptions.cpp,v 1.6 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -43,7 +43,8 @@ FWOptions::FWOptions()
     remStr("id"     );
 }
 
-FWOptions::FWOptions(const FWObject *root)
+FWOptions::FWOptions(const FWObject *root,bool prepopulate) :
+    FWObject(root,prepopulate)
 {
     remStr("comment");
     remStr("name"   );
@@ -60,12 +61,12 @@ void FWOptions::fromXML(xmlNodePtr root) throw(FWException)
         if(cur && !xmlIsBlankNode(cur))    
         {
 
-	        n=FROMXMLCAST(xmlGetProp(cur,TOXMLCAST("name")));
-	        assert(n!=NULL);
-	        cont=FROMXMLCAST( xmlNodeGetContent(cur) );
-	        if (cont)
+            n=FROMXMLCAST(xmlGetProp(cur,TOXMLCAST("name")));
+            assert(n!=NULL);
+            cont=FROMXMLCAST( xmlNodeGetContent(cur) );
+            if (cont)
             {
-    		    setStr(n, cont );
+                setStr(n, cont );
                 FREEXMLBUFF(n);
                 FREEXMLBUFF(cont);
             }
@@ -100,22 +101,22 @@ xmlNodePtr FWOptions::toXML(xmlNodePtr root) throw(FWException)
 
 const char *HostOptions::TYPENAME  ={"HostOptions"};
 HostOptions::HostOptions() : FWOptions() {}
-HostOptions::HostOptions(const FWObject *root) : FWOptions(root) {}
+HostOptions::HostOptions(const FWObject *root,bool prepopulate) : FWOptions(root,prepopulate) {}
 
 const char *FirewallOptions::TYPENAME  ={"FirewallOptions"};
 FirewallOptions::FirewallOptions() : FWOptions() {}
-FirewallOptions::FirewallOptions(const FWObject *root) : FWOptions(root) {}
+FirewallOptions::FirewallOptions(const FWObject *root,bool prepopulate) : FWOptions(root,prepopulate) {}
 
 const char *PolicyRuleOptions::TYPENAME={"PolicyRuleOptions"};
 PolicyRuleOptions::PolicyRuleOptions() : FWOptions() {}
-PolicyRuleOptions::PolicyRuleOptions(const FWObject *root) : FWOptions(root) {}
+PolicyRuleOptions::PolicyRuleOptions(const FWObject *root,bool prepopulate) : FWOptions(root,prepopulate) {}
 
 const char *NATRuleOptions::TYPENAME={"NATRuleOptions"};
 
 NATRuleOptions::NATRuleOptions() : FWOptions() {}
-NATRuleOptions::NATRuleOptions(const FWObject *root) : FWOptions(root) {}
+NATRuleOptions::NATRuleOptions(const FWObject *root,bool prepopulate) : FWOptions(root,prepopulate) {}
 
 const char *RoutingRuleOptions::TYPENAME={"RoutingRuleOptions"};
 RoutingRuleOptions::RoutingRuleOptions() : FWOptions() {}
-RoutingRuleOptions::RoutingRuleOptions(const FWObject *root) : FWOptions(root) {}
+RoutingRuleOptions::RoutingRuleOptions(const FWObject *root,bool prepopulate) : FWOptions(root,prepopulate) {}
 
