@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Firewall.cpp,v 1.9 2006/04/19 15:03:21 vkurland Exp $
+  $Id: Firewall.cpp,v 1.10 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -65,7 +65,7 @@ Firewall::Firewall()
     
 }
 
-Firewall::Firewall(const FWObject *root) : Host(root)
+Firewall::Firewall(const FWObject *root,bool prepopulate) : Host(root,prepopulate)
 {
     setStr("platform","unknown");
     setStr("host_OS" ,"unknown");
@@ -73,11 +73,13 @@ Firewall::Firewall(const FWObject *root) : Host(root)
     setInt("lastInstalled" ,0);
     setInt("lastCompiled" ,0);
 
-    add( new FirewallOptions() );
-    add( new Policy() );
-    add( new NAT() );
-    add( new Routing() );
-
+    if (prepopulate)
+    {
+        add( getRoot()->create(FirewallOptions::TYPENAME) );
+        add( getRoot()->create(Policy::TYPENAME) );
+        add( getRoot()->create(NAT::TYPENAME) );
+        add( getRoot()->create(Routing::TYPENAME) );
+    }
 }
 
 
@@ -242,6 +244,7 @@ FWObject& Firewall::duplicate(const FWObject *obj, bool preserve_id) throw(FWExc
         replaceRef(nat, o->getId(),   o1->getId()   );
         o1->destroyChildren();
 
+#ifdef USING_INTERFACE_POLICY
 	FWObject  *ipolicy  = o->getFirstByType(InterfacePolicy::TYPENAME);
         FWObject  *ipolicy1 = NULL;
         if (ipolicy)
@@ -250,6 +253,7 @@ FWObject& Firewall::duplicate(const FWObject *obj, bool preserve_id) throw(FWExc
             replaceRef(ipolicy1, obj->getId(), getId()       );
             replaceRef(ipolicy1, o->getId(),   o1->getId()   );
         }
+#endif
 
         FWObjectTypedChildIterator k=o->findByType(IPv4::TYPENAME);
         for ( ; k!=k.end(); ++k ) 
@@ -261,7 +265,7 @@ FWObject& Firewall::duplicate(const FWObject *obj, bool preserve_id) throw(FWExc
             {       
                 replaceRef(pol, oa->getId(),  oa1->getId() );
                 replaceRef(nat, oa->getId(),  oa1->getId() );
-                if (ipolicy1) replaceRef(ipolicy1, oa->getId(),  oa1->getId() );
+//                if (ipolicy1) replaceRef(ipolicy1, oa->getId(),  oa1->getId() );
             }
         }
 
@@ -275,7 +279,7 @@ FWObject& Firewall::duplicate(const FWObject *obj, bool preserve_id) throw(FWExc
             {       
                 replaceRef(pol, opa->getId(),  opa1->getId() );
                 replaceRef(nat, opa->getId(),  opa1->getId() );
-                if (ipolicy1) replaceRef(ipolicy1, opa->getId(),  opa1->getId() );
+//                if (ipolicy1) replaceRef(ipolicy1, opa->getId(),  opa1->getId() );
             }
         }
     }
