@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: IPAddress.cpp,v 1.3 2006/05/17 04:16:34 vkurland Exp $
+  $Id: IPAddress.cpp,v 1.4 2006/08/18 03:59:32 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -77,6 +77,10 @@ IPAddress::IPAddress()
     octets[0]=octets[1]=octets[2]=octets[3]=0;
 }
 
+IPAddress::~IPAddress()
+{
+}
+
 guint32 IPAddress::to32BitInt() const
 {
     guint32 x=0l;
@@ -326,6 +330,10 @@ Netmask::Netmask(int n)  throw(FWException)
     while (n!=0) { octets[i] |= m; m>>=1; n--; }
 }
 
+Netmask::~Netmask()
+{
+}
+
 int Netmask::getLength() const
 {
     if (toString()=="255.255.255.255") return 32;
