@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: IntervalGroup.cpp,v 1.3 2006/03/05 04:15:42 vkurland Exp $
+  $Id: IntervalGroup.cpp,v 1.5 2006/09/10 22:40:37 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -36,7 +36,8 @@ using namespace libfwbuilder;
 const char *IntervalGroup::TYPENAME={"IntervalGroup"};
 
 IntervalGroup::IntervalGroup() : Group() {}
-IntervalGroup::IntervalGroup(const FWObject *root) : FWObject(root) {}
+IntervalGroup::IntervalGroup(const FWObject *root,bool prepopulate) :
+    FWObject(root,prepopulate) {}
 
 IntervalGroup::~IntervalGroup() {}
 
@@ -52,7 +53,7 @@ bool  IntervalGroup::validateChild(FWObject *o)
 FWReference* IntervalGroup::createRef()
 {
 //    FWIntervalReference *ref=new FWIntervalReference();
-    FWIntervalReference *ref=FWIntervalReference::cast(getRoot()->create(FWIntervalReference::TYPENAME, true));
+    FWIntervalReference *ref=FWIntervalReference::cast(getRoot()->create(FWIntervalReference::TYPENAME));
     ref->setPointer(this);
     return ref;
 }
