@@ -6,7 +6,7 @@
 
   Author:  Vadim Zaliva lord@crocodile.org
 
-  $Id: Management.cpp,v 1.2 2004/09/08 05:34:50 vkurland Exp $
+  $Id: Management.cpp,v 1.4 2006/09/10 23:44:29 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -30,10 +30,13 @@
 
 #include <fwbuilder/libfwbuilder-config.h>
 
+#include <fwbuilder/FWObjectDatabase.h>
 #include <fwbuilder/Tools.h>
 #include <fwbuilder/Management.h>
 #include <fwbuilder/XMLTools.h>
 
+#include <iostream>
+
 using namespace std;
 using namespace libfwbuilder;
 
@@ -49,7 +52,8 @@ Management::Management()
     remStr("id"     );
 }
 
-Management::Management(const FWObject *root) : FWObject(root)
+Management::Management(const FWObject *root,bool prepopulate) :
+    FWObject(root,prepopulate)
 {
     // This object does not have standard attributes
     remStr("comment");
@@ -119,7 +123,8 @@ FWObject& Management::shallowDuplicate(const FWObject *o, bool preserve_id) thro
 {
     const Management *n=dynamic_cast<const Management *>(o);
     addr = n->getAddress();
-    return FWObject::shallowDuplicate(o, preserve_id);
+    FWObject::shallowDuplicate(o, preserve_id);
+    return *this;
 }
 
 bool Management::isEmpty() const
@@ -149,7 +154,9 @@ PolicyInstallScript *Management::getPolicyInstallScript()
 {
     PolicyInstallScript *res = dynamic_cast<PolicyInstallScript *>(getFirstByType(PolicyInstallScript::TYPENAME));
     if(!res)
-        add(res = new PolicyInstallScript());
+        add( res=
+  PolicyInstallScript::cast(getRoot()->create(PolicyInstallScript::TYPENAME) ));
+    //add(res = new PolicyInstallScript());
     return res;
 }
 
@@ -157,7 +164,9 @@ SNMPManagement *Management::getSNMPManagement()
 {
     SNMPManagement *res = dynamic_cast<SNMPManagement *>(getFirstByType(SNMPManagement::TYPENAME));
     if(!res)
-        add(res = new SNMPManagement());
+        add( res=
+             SNMPManagement::cast(getRoot()->create(SNMPManagement::TYPENAME)) );
+    //add(res = new SNMPManagement());
     return res;
 }
 
@@ -165,7 +174,9 @@ FWBDManagement *Management::getFWBDManagement()
 {
     FWBDManagement *res = dynamic_cast<FWBDManagement *>(getFirstByType(FWBDManagement::TYPENAME));
     if(!res)
-        add(res = new FWBDManagement());
+        add( res=
+             FWBDManagement::cast(getRoot()->create(FWBDManagement::TYPENAME)) );
+    //add(res = new FWBDManagement());
     return res;
 }
 
@@ -182,7 +193,8 @@ PolicyInstallScript::PolicyInstallScript()
     enabled = false ;
 }
 
-PolicyInstallScript::PolicyInstallScript(const FWObject *root) : FWObject(root)
+PolicyInstallScript::PolicyInstallScript(const FWObject *root,bool prepopulate) :
+    FWObject(root,prepopulate)
 {
     // This object does not have standard attributes
     remStr("comment");
@@ -249,7 +261,8 @@ FWObject& PolicyInstallScript::shallowDuplicate(const FWObject *o, bool preserve
     command   =  n->getCommand();
     arguments =  n->getArguments();
     enabled   =  n->isEnabled();
-    return FWObject::shallowDuplicate(o, preserve_id);
+    FWObject::shallowDuplicate(o, preserve_id);
+    return *this;
 }
 
 const string& PolicyInstallScript::getCommand() const
@@ -285,7 +298,8 @@ SNMPManagement::SNMPManagement()
     enabled = false ;
 }
 
-SNMPManagement::SNMPManagement(const FWObject *root) : FWObject(root)
+SNMPManagement::SNMPManagement(const FWObject *root,bool prepopulate) :
+    FWObject(root,prepopulate)
 {
     // This object does not have standard attributes
     remStr("comment");
@@ -352,7 +366,8 @@ FWObject& SNMPManagement::shallowDuplicate(const FWObject *o, bool preserve_id)
     read_community  =  n->getReadCommunity();
     write_community =  n->getWriteCommunity();
     enabled         =  n->isEnabled();
-    return FWObject::shallowDuplicate(o, preserve_id);
+    FWObject::shallowDuplicate(o, preserve_id);
+    return *this;
 }
 
 const string& SNMPManagement::getReadCommunity () const
@@ -392,8 +407,13 @@ FWBDManagement::FWBDManagement()
     remStr("id"     );
 }
 
-FWBDManagement::FWBDManagement(const FWObject *root) : FWObject(root)
+FWBDManagement::FWBDManagement(const FWObject *root,bool prepopulate) :
+    FWObject(root,prepopulate)
 {
+    port = -1 ;
+    key  = NULL ;
+    enabled = false ;
+
     // This object does not have standard attributes
     remStr("comment");
     remStr("name"   );
@@ -403,7 +423,7 @@ FWBDManagement::FWBDManagement(const FWObject *root) : FWObject(root)
 
 FWBDManagement::~FWBDManagement()
 {
-    delete key;
+    if (key) delete key;
 }
 
 bool FWBDManagement::isEmpty() const
@@ -484,11 +504,32 @@ bool FWBDManagement::cmp(const FWObject *obj) throw(FWException)
 FWObject& FWBDManagement::shallowDuplicate(const FWObject *o, bool preserve_id) throw(FWException)
 {
     const FWBDManagement *n=dynamic_cast<const FWBDManagement *>(o);
-    port        = n->getPort   ();
+#if 0
+    cerr << "FWBDManagement::shallowDuplicate" << endl;
+    cerr << "this:" << endl;
+    dump(false,false);
+    cerr << "Port: " << port << endl;
+    cerr << "identity_id: " << identity_id << endl;
+    cerr << "enabled: " << enabled << endl;
+    cerr << "key: " << key << endl;
+    cerr << endl;
+
+    cerr << "n:" << endl;
+    ((FWObject*)n)->dump(false,false);
+    cerr << "Port: " << n->port << endl;
+    cerr << "identity_id: " << n->identity_id << endl;
+    cerr << "enabled: " << n->enabled << endl;
+    cerr << "key: " << n->key << endl;
+    cerr << endl;
+#endif
+
+    port        = n->getPort();
     identity_id = n->getIdentityId();
     enabled     = n->isEnabled();
-    delete key;  key=n->key;
-    return FWObject::shallowDuplicate(o, preserve_id);
+    if (key) delete key;
+    key=n->key;
+    FWObject::shallowDuplicate(o, preserve_id);
+    return *this;
 }
 
 int FWBDManagement::getPort() const
@@ -518,12 +559,12 @@ const Key *FWBDManagement::getPublicKey () const
 
 void FWBDManagement::setPublicKey(const Key &k) 
 {
-    delete key;
+    if (key) delete key;
     key = new Key(k);
 }
 
 void FWBDManagement::removePublicKey()
 {
-    delete key;
+    if (key) delete key;
     key = NULL;
 }
