@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler.cpp,v 1.17 2006/09/21 06:15:21 vkurland Exp $
+  $Id: PolicyCompiler.cpp,v 1.19 2007/01/07 01:34:41 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -840,9 +840,10 @@ bool  PolicyCompiler::ConvertToAtomic::processNext()
 
 std::deque<Rule*>::iterator 
 PolicyCompiler::findMoreGeneralRule::find_more_general_rule(PolicyRule *rule,
-                                                      bool check_interface,
-                                                      const std::deque<Rule*>::iterator &start_here,
-                                                      const std::deque<Rule*>::iterator &stop_here)
+                                                            bool check_interface,
+                                                            const std::deque<Rule*>::iterator &start_here,
+                                                            const std::deque<Rule*>::iterator &stop_here,
+                                                            bool reverse)
 {
     PolicyCompiler *pcomp=dynamic_cast<PolicyCompiler*>(compiler);
     if (compiler->debug>=9) 
@@ -860,7 +861,11 @@ PolicyCompiler::findMoreGeneralRule::find_more_general_rule(PolicyRule *rule,
 	if (! check_interface || 
 	    (rule->getInterfaceId()==r->getInterfaceId()) ) 
         {
-            bool cr=pcomp->checkForShadowing( *rule , *r );
+            bool cr = false;
+            if (reverse)
+                cr = pcomp->checkForShadowing( *r , *rule );
+            else
+                cr = pcomp->checkForShadowing( *rule , *r );
             if ( cr ) 
             {
                 if (compiler->debug>=9) 
@@ -893,22 +898,22 @@ bool PolicyCompiler::DetectShadowing::processNext()
     if (rule->isFallback()) return true; // do not check fallback  ..
     if (rule->isHidden())   return true; //  ... and hidden rules
 
-    std::deque<Rule*>::iterator i=find_more_general_rule(rule,true,
+    std::deque<Rule*>::iterator i=find_more_general_rule(rule,
+                                                         true,
                                                          rules_seen_so_far.begin(),
-                                                         rules_seen_so_far.end());
+                                                         rules_seen_so_far.end(),
+                                                         false);
     if (i!=rules_seen_so_far.end()) 
     {
-        Rule *r=dynamic_cast<Rule*>(*i);
+        Rule *r = *i;
 /*
  * find_more_general finds more general _or_ equivalent rule
  */
         if (r && r->getAbsRuleNumber() != rule->getAbsRuleNumber() && 
             ! (*r == *rule) ) 
         {
-            rules_seen_so_far.push_back(rule);
-
             compiler->abort("Rule '" + r->getLabel() +
-             "' shades rule '" + rule->getLabel() + "'  below it");
+             "' shadows rule '" + rule->getLabel() + "'  below it");
         }
     }
 
@@ -917,6 +922,38 @@ bool PolicyCompiler::DetectShadowing::processNext()
     return true;
 }
 
+bool PolicyCompiler::DetectShadowingForNonTerminatingRules::processNext()
+{
+    PolicyRule *rule;
+    rule=getNext(); if (rule==NULL) return false;
+
+    tmp_queue.push_back(rule);  // to pass it to the next processor, if any
+    if (rule->isFallback()) return true; // do not check fallback  ..
+    if (rule->isHidden())   return true; //  ... and hidden rules
+
+    std::deque<Rule*>::iterator i=find_more_general_rule(rule,
+                                                         true,
+                                                         rules_seen_so_far.begin(),
+                                                         rules_seen_so_far.end(),
+                                                         true);   // <<<<<<< NB!
+    if (i!=rules_seen_so_far.end()) 
+    {
+        Rule *r = *i;
+/*
+ * find_more_general finds more general _or_ equivalent rule
+ */
+        if (r && r->getAbsRuleNumber() != rule->getAbsRuleNumber() && 
+            ! (*r == *rule) ) 
+        {
+            compiler->abort("Non-terminating rule '" + rule->getLabel() +
+             "' shadows rule '" + r->getLabel() + "'  above it");
+        }
+    }
+
+    rules_seen_so_far.push_back(rule);
+    return true;
+}
+
 bool PolicyCompiler::MACFiltering::checkRuleElement(RuleElement *re)
 {
     bool  res=true;
