@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: Preprocessor.cpp,v 1.4 2006/05/21 04:42:50 vkurland Exp $
+  $Id: Preprocessor.cpp,v 1.6 2006/10/25 05:16:12 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,6 +27,8 @@
 #include "Preprocessor.h"
 
 #include "fwbuilder/MultiAddress.h"
+#include "fwbuilder/Rule.h"
+#include "fwbuilder/Firewall.h"
 
 #include <iostream>
 
@@ -39,7 +41,7 @@ string Preprocessor::myPlatformName() { return "generic_preprocessor"; }
 Preprocessor::~Preprocessor() {}
 
 Preprocessor::Preprocessor(FWObjectDatabase *_db, const string &fwname) :
-    Compiler(_db)
+    Compiler(_db, fwname)
 {
     // This is the main difference between Preprocessor and other
     // compilers.  All compilers create a copy of the whole database
@@ -55,12 +57,23 @@ void Preprocessor::convertObject(FWObject *obj)
     {
         if (adt->isCompileTime())
         {
-            try
+            // check if this object is used anywhere
+            set<FWObject*> resset;
+            obj->getRoot()->findWhereUsed(obj,obj->getRoot(),resset);
+            
+            set<FWObject*>::iterator i;
+            for (i=resset.begin(); i!=resset.end(); ++i)
             {
-                adt->loadFromSource();
-            } catch (FWException &ex)
-            {
-                abort(ex.toString());
+                if ( (*i)->getId()==fw->getId() )
+                {
+                    try
+                    {
+                        adt->loadFromSource();
+                    } catch (FWException &ex)
+                    {
+                        abort(ex.toString());
+                    }
+                }
             }
         }
     }
